#ifndef FREERDP_BUILD_CONFIG_H
#define FREERDP_BUILD_CONFIG_H

#define FREERDP_DATA_PATH "/usr/pkg/share/freerdp2"
#define FREERDP_KEYMAP_PATH ""
#define FREERDP_PLUGIN_PATH "lib/freerdp2"

#define FREERDP_INSTALL_PREFIX "/usr/pkg"

#define FREERDP_LIBRARY_PATH "lib"

#define FREERDP_ADDIN_PATH "lib/freerdp2"

#define FREERDP_SHARED_LIBRARY_SUFFIX ".so"
#define FREERDP_SHARED_LIBRARY_PREFIX  "lib"

#define FREERDP_VENDOR_STRING "FreeRDP"
#define FREERDP_PRODUCT_STRING "FreeRDP"

#define FREERDP_PROXY_PLUGINDIR "/tmp/pkgbuild/net/freerdp2/work.sparc64/freerdp-2.11.7/cmake-pkgsrc-build/server/proxy/plugins"

#endif /* FREERDP_BUILD_CONFIG_H */
